# remirepo/fedora spec file for php-tecnickcom-tc-lib-pdf-encrypt
#
# SPDX-FileCopyrightText:  Copyright 2016-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%global gh_commit    34bc2b37314ee34180f8cd85dc4d19956d7c5985
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-pdf-encrypt
%global php_project  %{_datadir}/php/Com/Tecnick/Pdf/Encrypt
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.1.15
Release:        1%{?dist}
Summary:        PHP library to encrypt data for PDF

License:        LGPL-3.0-or-later
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with_tests}
# For tests
BuildRequires:  php(language) >= 8.1
BuildRequires:  php-date
BuildRequires:  php-hash
BuildRequires:  php-openssl
BuildRequires:  php-pcre
BuildRequires:  php-posix
%global phpunit %{_bindir}/phpunit10
BuildRequires:  phpunit10 >= 10.5.40
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": ">=8.1",
#        "ext-date": "*",
#        "ext-hash": "*",
#        "ext-openssl": "*",
#        "ext-pcre": "*",
Requires:       php(language) >= 8.1
Requires:       php-date
Requires:       php-hash
Requires:       php-openssl
Requires:       php-pcre
# From composer.json, "suggest": {
#        "ext-posix": "*"
Requires:       php-posix
# From phpcompatinfo report for version 1.5.0
# none
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library to encrypt data for PDF.

The initial source code has been extracted from TCPDF (http://www.tcpdf.org).


%prep
%setup -q -n %{gh_project}-%{gh_commit}

: Sanity check
grep -q '^%{version}$' VERSION


%build
phpab --template fedora --output src/autoload.php src


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
date_default_timezone_set("UTC");
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in php php81 php82 php83 php84; do
   if which $cmdarg; then
      set $cmdarg
      cp phpunit.xml.dist phpunit.xml
      $1 ${2:-%{phpunit}} --migrate-configuration || :
      $1 ${2:-%{phpunit}} --no-coverage || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%license LICENSE
%doc composer.json
%doc *.md
%dir %{_datadir}/php/Com
%dir %{_datadir}/php/Com/Tecnick
%dir %{_datadir}/php/Com/Tecnick/Pdf
%{php_project}


%changelog
* Sat May 31 2025 Remi Collet <remi@remirepo.net> - 2.1.15-1
- update to 2.1.15 (no change)

* Thu May 15 2025 Remi Collet <remi@remirepo.net> - 2.1.14-1
- update to 2.1.14 (no change)

* Mon Apr 28 2025 Remi Collet <remi@remirepo.net> - 2.1.13-1
- update to 2.1.13 (no change)

* Fri Feb  7 2025 Remi Collet <remi@remirepo.net> - 2.1.11-1
- update to 2.1.11 (no change)

* Thu Dec 26 2024 Remi Collet <remi@remirepo.net> - 2.1.10-1
- update to 2.1.10
- raise dependency on PHP 8.1

* Mon Dec 23 2024 Remi Collet <remi@remirepo.net> - 2.1.9-1
- update to 2.1.9 (no change)
- re-license spec file to CECILL-2.1

* Mon Nov 25 2024 Remi Collet <remi@remirepo.net> - 2.1.8-1
- update to 2.1.8 (no change)

* Mon Oct 28 2024 Remi Collet <remi@remirepo.net> - 2.1.7-1
- update to 2.1.7 (no change)

* Mon Sep  9 2024 Remi Collet <remi@remirepo.net> - 2.1.6-1
- update to 2.1.6 (no change)

* Fri Aug 30 2024 Remi Collet <remi@remirepo.net> - 2.1.5-1
- update to 2.1.5

* Mon Aug 19 2024 Remi Collet <remi@remirepo.net> - 2.1.4-1
- update to 2.1.4 (no change)

* Fri Apr 12 2024 Remi Collet <remi@remirepo.net> - 2.1.2-1
- update to 2.1.2

* Wed Nov 29 2023 Remi Collet <remi@remirepo.net> - 2.1.1-1
- update to 2.1.1

* Tue Nov 28 2023 Remi Collet <remi@remirepo.net> - 2.0.8-1
- update to 2.0.8 (no change)

* Tue Nov 28 2023 Remi Collet <remi@remirepo.net> - 2.0.7-2
- use legacy openssl config for tests

* Wed Nov 22 2023 Remi Collet <remi@remirepo.net> - 2.0.7-1
- update to 2.0.7
- raise dependency on PHP 8

* Mon Oct 23 2023 Remi Collet <remi@remirepo.net> - 1.6.35-1
- update to 1.6.35 (no change)

* Thu Oct 12 2023 Remi Collet <remi@remirepo.net> - 1.6.33-1
- update to 1.6.33

* Tue Oct 10 2023 Remi Collet <remi@remirepo.net> - 1.6.28-1
- update to 1.6.28

* Tue Oct 10 2023 Remi Collet <remi@remirepo.net> - 1.6.25-1
- update to 1.6.25

* Fri Sep  8 2023 Remi Collet <remi@remirepo.net> - 1.6.24-1
- update to 1.6.24 (no change)

* Wed May 24 2023 Remi Collet <remi@remirepo.net> - 1.6.20-1
- update to 1.6.20 (no change)

* Fri May  5 2023 Remi Collet <remi@remirepo.net> - 1.6.19-1
- update to 1.6.19 (no change)

* Thu May  4 2023 Remi Collet <remi@remirepo.net> - 1.6.17-1
- update to 1.6.17 (no change)

* Wed May  3 2023 Remi Collet <remi@remirepo.net> - 1.6.15-1
- update to 1.6.15 (no change)

* Thu Dec 22 2022 Remi Collet <remi@remirepo.net> - 1.6.14-1
- update to 1.6.14

* Tue Jun 14 2022 Remi Collet <remi@remirepo.net> - 1.6.10-1
- update to 1.6.10 (no change)

* Mon Jan  3 2022 Remi Collet <remi@remirepo.net> - 1.6.7-1
- update to 1.6.7 (no change)

* Thu Nov 11 2021 Remi Collet <remi@remirepo.net> - 1.6.4-2
- skip test failing with OpenSSL 3.0 reported as
  https://github.com/tecnickcom/tc-lib-pdf-encrypt/issues/10

* Mon Feb  8 2021 Remi Collet <remi@remirepo.net> - 1.6.4-1
- update to 1.6.4 (no change)

* Mon Dec 21 2020 Remi Collet <remi@remirepo.net> - 1.6.1-1
- update to 1.6.1
- switch to classmap autoloader

* Fri Jan  3 2020 Remi Collet <remi@remirepo.net> - 1.5.10-1
- update to 1.5.10 (no change)

* Thu Jan  2 2020 Remi Collet <remi@remirepo.net> - 1.5.9-1
- update to 1.5.9 (no change)

* Fri Sep 20 2019 Remi Collet <remi@remirepo.net> - 1.5.8-1
- update to 1.5.8 (no change)

* Mon Jun 25 2018 Remi Collet <remi@remirepo.net> - 1.5.7-1
- update to 1.5.7 (no change)

* Mon May 14 2018 Remi Collet <remi@remirepo.net> - 1.5.6-1
- update to 1.5.6 (no change)
- switch to phpunit7

* Tue Jan  2 2018 Remi Collet <remi@remirepo.net> - 1.5.4-1
- Update to 1.5.4

* Sun Oct 29 2017 Remi Collet <remi@remirepo.net> - 1.5.3-1
- Update to 1.5.3
- use phpunit6 when available

* Sun Feb 12 2017 Remi Collet <remi@fedoraproject.org> - 1.5.2-1
- update to 1.5.2 (no change)

* Wed Feb  8 2017 Remi Collet <remi@fedoraproject.org> - 1.5.0-1
- update to 1.5.0
- drop dependency on php-mcrypt

* Mon Feb  6 2017 Remi Collet <remi@fedoraproject.org> - 1.4.4-1
- update to 1.4.4 (no change)
- open https://github.com/tecnickcom/tc-lib-pdf-encrypt/issues/4 - 7.1 failure
- open https://github.com/tecnickcom/tc-lib-pdf-encrypt/pull/5 add 7.1 to travis
- open https://github.com/tecnickcom/tc-lib-pdf-encrypt/pull/6 better exception

* Fri Sep  2 2016 Remi Collet <remi@fedoraproject.org> - 1.4.3-1
- update to 1.4.3

* Tue Jun 14 2016 Remi Collet <remi@fedoraproject.org> - 1.4.0-1
- update to 1.4.0 (no change)

* Fri Mar  4 2016 Remi Collet <remi@fedoraproject.org> - 1.3.2-1
- update to 1.3.2 (no change)

* Fri Jan 15 2016 Remi Collet <remi@fedoraproject.org> - 1.3.0-1
- initial package, version 1.3.0

